==> kubernetes-client-4.10.3-sources.jar: io/fabric8/kubernetes/client/dsl/internal/core/v1/APIServiceOperationsImpl.java <==

                                          
  

package io.fabric8.kubernetes.client.dsl.internal.core.v1;

import io.fabric8.kubernetes.client.Config;
import io.fabric8.kubernetes.client.dsl.Resource;
import io.fabric8.kubernetes.client.dsl.base.HasMetadataOperation;
import io.fabric8.kubernetes.client.dsl.NonNamespaceOperation;
import io.fabric8.kubernetes.client.utils.ApiVersionUtil;
import io.fabric8.kubernetes.client.dsl.base.OperationContext;

import okhttp3.OkHttpClient;

import io.fabric8.kubernetes.api.model.DoneableAPIService;
import io.fabric8.kubernetes.api.model.APIService;
import io.fabric8.kubernetes.api.model.APIServiceList;
import io.fabric8.kubernetes.api.model.DoneableAPIService;

import java.util.Map;
import java.util.TreeMap;


public class APIServiceOperationsImpl extends HasMetadataOperation<APIService, APIServiceList, DoneableAPIService, Resource<APIService, DoneableAPIService>> {

  public APIServiceOperationsImpl(OkHttpClient client, Config config) {
    this(client, config, null);
  }

  public APIServiceOperationsImpl(OkHttpClient client, Config config, String namespace) {
    this(new OperationContext().withOkhttpClient(client).withConfig(config).withNamespace(namespace).withPropagationPolicy(DEFAULT_PROPAGATION_POLICY));
  }

  public APIServiceOperationsImpl(OperationContext context) {
    super(context.withApiGroupName("apiregistration.k8s.io")
    .withApiGroupVersion("v1")
    .withPlural("apiservices"));
    this.type = APIService.class;
    this.listType = APIServiceList.class;
    this.doneableType = DoneableAPIService.class;
  }

  public APIServiceOperationsImpl newInstance(OperationContext context) {
    return new APIServiceOperationsImpl(context);
  }

  @Override
  public boolean isResourceNamespaced() {
    return false;
  }
}

==> kubernetes-client-5.4.1-sources.jar: io/fabric8/kubernetes/client/dsl/internal/core/v1/APIServiceOperationsImpl.java <==

                                          
  

package io.fabric8.kubernetes.client.dsl.internal.core.v1;

import io.fabric8.kubernetes.api.builder.Visitor;
import io.fabric8.kubernetes.client.Config;
import io.fabric8.kubernetes.client.dsl.Resource;
import io.fabric8.kubernetes.client.dsl.base.HasMetadataOperation;
import io.fabric8.kubernetes.client.dsl.NonNamespaceOperation;
import io.fabric8.kubernetes.client.utils.ApiVersionUtil;
import io.fabric8.kubernetes.client.dsl.base.OperationContext;

import okhttp3.OkHttpClient;

import io.fabric8.kubernetes.api.model.APIService;
import io.fabric8.kubernetes.api.model.APIServiceBuilder;
import io.fabric8.kubernetes.api.model.APIServiceList;

import java.util.Map;
import java.util.TreeMap;


public class APIServiceOperationsImpl extends HasMetadataOperation<APIService, APIServiceList, Resource<APIService>> {

  public APIServiceOperationsImpl(OkHttpClient client, Config config) {
    this(client, config, null);
  }

  public APIServiceOperationsImpl(OkHttpClient client, Config config, String namespace) {
    this(new OperationContext().withOkhttpClient(client).withConfig(config).withNamespace(namespace).withPropagationPolicy(DEFAULT_PROPAGATION_POLICY));
  }

  public APIServiceOperationsImpl(OperationContext context) {
    super(context.withApiGroupName("apiregistration.k8s.io")
    .withApiGroupVersion("v1")
    .withPlural("apiservices"));
    this.type = APIService.class;
    this.listType = APIServiceList.class;
  }

  public APIServiceOperationsImpl newInstance(OperationContext context) {
    return new APIServiceOperationsImpl(context);
  }

  @Override
  public APIService edit(Visitor... visitors) {
    return patch(new APIServiceBuilder(getMandatory()).accept(visitors).build());
  }

  @Override
  public boolean isResourceNamespaced() {
    return false;
  }
}
